@@ -1309,7 +1309,7 @@ def parallelize_anything(
 
 def do_corpus_embeddings_gpu(
     corpus: pd.Series, 
-    col: str,
+    used_embedder: Literal['multi-qa-mpnet-base-cos-v1','multi-qa-mpnet-base-dot-v1' , 'all-mpnet-base-v2', None]='multi-qa-mpnet-base-cos-v1',
     target_devices: Literal['cuda', 'cpu', None]='cuda',
     with_gpu_mode_process: bool=False,
     with_config_gpu_params: bool=False,
@@ -1347,7 +1347,7 @@ def do_corpus_embeddings_gpu(
         ):
             ## https://discuss.pytorch.org/t/keep-getting-cuda-oom-error-with-pytorch-failing-to-allocate-all-free-memory/133896/6
             os.environ["PYTORCH_CUDA_ALLOC_CONF"]=f'max_split_size_mb:{max_split_size_mb}'
-            mp.set_start_method('spawn')
+            multiprocessing.set_start_method(f'{set_start_method}', force=True)
 
         def config_gpu_params(
             num_gpus: Union[int, list] = 1,
@@ -1373,8 +1373,7 @@ def do_corpus_embeddings_gpu(
 
         start = time.time()
 
-        # embedder = SentenceTransformer("multi-qa-mpnet-base-cos-v1")
-        embedder = SentenceTransformer("multi-qa-mpnet-base-dot-v1")
+        embedder = SentenceTransformer(used_embedder)
 
         if target_devices is None:
             if torch.cuda.is_available():
@@ -1534,7 +1533,7 @@ def do_corpus_embeddings(
 
 
 def do_semantic_information_retrieval_gpu(
-    col: str,
+    print_col: str,
     sentences1: pd.DataFrame,
     sentences2: pd.DataFrame,
     corpus_embeddings: np.ndarray,
@@ -1542,6 +1541,7 @@ def do_semantic_information_retrieval_gpu(
     embedder: SentenceTransformer,
     mvp: bool = False,
     print_results: bool = True,
+    sentences_1_col_name: str = 'keywords'
 ) -> None:
     """Consulta informação
 
@@ -1562,11 +1562,11 @@ def do_semantic_information_retrieval_gpu(
     if type(sentences1) == str:
         sentences1 = pd.DataFrame(
             {
-                'keywords':[sentences1]
+                sentences_1_col_name : [sentences1]
             }
         )
     if type(sentences1) == pd.DataFrame:
-        sentences1['keywords'] = sentences1['keywords'].apply(lambda x: apply_parser_clean(x, forward_from='clean'))
+        sentences1[sentences_1_col_name] = sentences1[sentences_1_col_name].apply(lambda x: apply_parser_clean(x, forward_from='clean'))
     else:
         raise TypeError('sentences1 must be a pd.DataFrame')
     for i, _ in enumerate(sentences1):
@@ -1612,7 +1612,7 @@ def do_semantic_information_retrieval_gpu(
             if print_results:
                 print(
                     'Texto:\n',
-                    str(row[col]),
+                    str(row[print_col]),
                     '\n\nCorpus:\n',
                     str(row['features_corpus']),
                     "\n\n=== SEMANTIC SEARCH ===\n",
@@ -1620,7 +1620,7 @@ def do_semantic_information_retrieval_gpu(
                 )
                 print("=======================\n")
         if mvp:
-            return df_semantic_return, sentences1['keywords']
+            return df_semantic_return, sentences1[sentences_1_col_name]
         else:
             return df_semantic_return
         # break  #
@@ -1788,7 +1788,7 @@ def filter_onehot_by_frequency(
     print(f'df_x_filter.shape: {df_x_filter.shape}')
     print(f'df_y_filter.shape: {df_y_filter.shape}')
     print(f'min_freq: {min_freq}')
-    return df_x_filter, df_y_filter
+    return df_x_filter.reset_index(drop=True), df_y_filter.reset_index(drop=True)
 
 
 def print_all_important_metrics(model, X_test, y_test, classifier_description: str):
@@ -1845,6 +1845,7 @@ def run_model_OvR_onehot(
     stratify: bool = False,
     sparse: bool = False,
     model_function = SGDClassifier(),
+    classifier_chain_ascending: bool = False,
     ):
     from sklearn.preprocessing import StandardScaler, PowerTransformer, MinMaxScaler
     from sklearn.svm import LinearSVC
@@ -1888,7 +1889,7 @@ def run_model_OvR_onehot(
     
     chain_model = ClassifierChain(
         clf,
-        order=df_y_new.sum().reset_index(drop=True).sort_values(ascending=False).index
+        order=df_y_new.sum().reset_index(drop=True).sort_values(ascending=classifier_chain_ascending).index
     ).fit(X_train, y_train)
     print_all_important_metrics(chain_model, X_test, y_test, f'Classifier Chain{[" - Sem Stratify"," - Stratify"][stratify]}')
     return y_train, y_test, y.columns, ovr_model, multi_model, chain_model
\ No newline at end of file
